/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid.activities;

import android.annotation.SuppressLint;
import android.os.Bundle;
import android.view.View;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.FrameLayout;
import android.widget.ProgressBar;
import android.widget.TextView;

import com.danielme.muspyforandroid.Constants;
import com.danielme.muspyforandroid.R;
import com.danielme.muspyforandroid.activities.base.AbstractBrowserActivity;

/**
 * Embedded WebView.
 * @author Daniel Medina (danielme.com)
 * @since 1.0
 */
public class WebBrowserActivity extends AbstractBrowserActivity
{

	/* ************************************************************ */
	/*							FIELDS            					*/
	/* ************************************************************ */

	private String url;
	private ProgressBar progressBar;

	/* ************************************************************ */
	/*							OVERRIDE           					*/
	/* ************************************************************ */

	@SuppressLint("SetJavaScriptEnabled")
	@Override
	public void onCreate(Bundle icicle)
	{
		super.onCreate(icicle);
		setContentView(R.layout.webbrowser);

		browser = (WebView) findViewById(R.id.webkit);
		progressBar = (ProgressBar) findViewById(R.id.progressbar);
		url = getIntent().getExtras().getString(Constants.PARAM_URL);
		browser.loadUrl(url);
		browser.getSettings().setJavaScriptEnabled(true);
		browser.getSettings().setBuiltInZoomControls(true);
		browser.setWebViewClient(new WebViewClient()
		{
			@Override
			public boolean shouldOverrideUrlLoading(WebView view, String url)
			{
				return false;
			}
		});
		browser.setWebChromeClient(new WebChromeClient()
		{
			@Override
			public void onProgressChanged(WebView view, int progress)
			{
				progressBar.setProgress(0);
				FrameLayout progressBarLayout = (FrameLayout) findViewById(R.id.progressBarLayout);
				progressBarLayout.setVisibility(View.VISIBLE);
				WebBrowserActivity.this.setProgress(progress * 1000);

				TextView progressStatus = (TextView) findViewById(R.id.progressStatus);
				progressStatus.setText(progress + " %");
				progressBar.incrementProgressBy(progress);

				if (progress == 100)
				{
					progressBarLayout.setVisibility(View.GONE);
				}
			}

			 @Override
	         public void onReceivedTitle(WebView view, String title)
	         {
				 WebBrowserActivity.this.setTitle(getString(R.string.app_name) + " - " + WebBrowserActivity.this.browser.getTitle());
	         }
		});
	}

	

}