/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid.activities.adapters;

import java.util.List;
import java.util.Map;

import android.content.Context;
import android.view.View;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.ImageButton;
import android.widget.TextView;

import com.danielme.muspyforandroid.Constants;
import com.danielme.muspyforandroid.R;
import com.danielme.muspyforandroid.activities.adapters.template.ICustomListAdapterHolderPattern;
import com.danielme.muspyforandroid.model.Artist;

/**
 * holder for Artists ListView.
 * @author Daniel Medina (danielme.com)
 * @since 1.0
 */
public class MyArtistsAdapter implements ICustomListAdapterHolderPattern
{

	/* ************************************************************ */
	/*							FIELDS            					*/
	/* ************************************************************ */

	private TextView textViewArtist;
	private CheckBox checkBoxDelete;
	private ImageButton imageButtonInfo;

	/* ************************************************************ */
	/*							OVERRIDE           					*/
	/* ************************************************************ */

	@Override
	public void populateHolder(View row, int position, List<?> objects, Context context, Map<?, ?> params)
	{
		final Artist artist = (Artist) objects.get(position);
		StringBuilder name = new StringBuilder(artist.getName());
		if (artist.getDisambiguation() != null && artist.getDisambiguation().length() > 0)
		{
			name.append(" (" + artist.getDisambiguation() + ")");
		}
		textViewArtist.setText(name);
		checkBoxDelete.setTag(artist.getName());
		//tag data is for methon onclick-showArtistInfo
		imageButtonInfo.setTag(artist.getMbid() + Constants.INFO_SEPARATOR + artist.getName());
		checkBoxDelete.setChecked(artist.isChecked());

		checkBoxDelete.setOnCheckedChangeListener(new OnCheckedChangeListener()
		{
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked)
			{
				//asegura que se modifica el artista originalmente asociado a este checkbox
				//para evitar que al reciclar la vista se reinicie el artista que antes se mostraba en esta
				//row. Es imprescindible tagear el artista antes de establecer el valor del checkbox
				if (artist.getName().equals(buttonView.getTag().toString()))
				{
					artist.setChecked(isChecked);
				}
			}
		});

	}

	@Override
	public void cacheWidgets(View row)
	{
		textViewArtist = (TextView) row.findViewById(R.id.artist);
		checkBoxDelete = (CheckBox) row.findViewById(R.id.checkBox);
		imageButtonInfo = (ImageButton) row.findViewById(R.id.imageButtonInfo);
		imageButtonInfo.setFocusable(false);
	}


}