/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid.activities.adapters;

import java.util.List;
import java.util.Map;

import android.content.Context;
import android.view.View;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;

import com.danielme.muspyforandroid.Constants;
import com.danielme.muspyforandroid.R;
import com.danielme.muspyforandroid.activities.adapters.template.ICustomListAdapterHolderPattern;
import com.danielme.muspyforandroid.model.Artist;
import com.danielme.muspyforandroid.utils.Utils;

/**
 * Holder for the ListView with the results of the search
 * @author Daniel Medina (danielme.com)
 * @since 1.0
 */
public class SearchArtistAdapter implements ICustomListAdapterHolderPattern
{
	private TextView artistTextView;
	private ImageView addButton;
	private ImageButton imageButtonInfo;


	@Override
	public void populateHolder(View row, int position, List<?> objects, Context context, Map<?, ?> params)
	{
		Artist artist = (Artist) objects.get(position);
		StringBuilder name = new StringBuilder(artist.getName());
		if (Utils.hasText(artist.getDisambiguation()))
		{
			name.append(" (" + artist.getDisambiguation() + ")");
		}
		artistTextView.setText(name);		

		//i have to know the artist
		addButton.setTag(artist);
		imageButtonInfo.setTag(artist.getMbid() + Constants.INFO_SEPARATOR + artist.getName());
	}

	@Override
	public void cacheWidgets(View row)
	{
		addButton = (ImageView) row.findViewById(R.id.add);
		addButton.setFocusable(false);
		artistTextView = (TextView) row.findViewById(R.id.artist);
		imageButtonInfo = (ImageButton) row.findViewById(R.id.imageButtonInfo);
		imageButtonInfo.setFocusable(false);
	}

}