/*
 * Copyright (C) 2012-2013 Daniel Medina <http://danielme.com>
 * 
 * This file is part of "Muspy for Android".
 * 
 * "Muspy for Android" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * "Muspy for Android" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with this program.  If not, see <http://www.gnu.org/licenses/gpl-3.0.html/>
 */
package com.danielme.muspyforandroid.activities.adapters.template;


import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

/**
 * An adapter that uses {@link ICustomListAdapterHolderPattern}
 * @author Daniel Medina (danielme.com)
 * @since 1.0
 *
 */
public  class CustomListAdapter extends BaseAdapter
{

	/* ************************************************************ */
	/*							FIELDS            					*/
	/* ************************************************************ */
	
	private int textViewResourceId = 0;
	private final List<?> objects;
	private final Class<?> holderClass;
	private final Context context;
	private Map<?, ?> params;


	/* ************************************************************ */
	/*							CONSTRUCTOR            				*/
	/* ************************************************************ */
	
	public CustomListAdapter(Context context, int idLayoutEntradaLista, List<?> objects, Class<?> holderClass)
	{
		super();
		this.textViewResourceId = idLayoutEntradaLista;
		this.objects = objects;
		this.holderClass = holderClass;
		this.context = context;
	}
	
	//additional parameters
	public CustomListAdapter(Context context, int idLayoutEntradaLista, List<?> objects, Class<?> holderClass, Map<?, ?> params)
	{
		super();
		this.textViewResourceId = idLayoutEntradaLista;
		this.objects = objects;
		this.holderClass = holderClass;
		this.context = context;
		this.params = params;
	}
	
	/* ************************************************************ */
	/*							OVERRIDE            				*/
	/* ************************************************************ */
	
	/**
	 * Uses View Holder Pattern.
	 * @see android.widget.Adapter#getView(int, android.view.View, android.view.ViewGroup)
	 */
	@Override
	public View getView(int position, View convertView, ViewGroup parent)
	{
		
		View row = convertView;
		if (row == null)
		{			
			LayoutInflater layoutInflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			row = layoutInflater.inflate(textViewResourceId, parent, false);
		}
		
		ICustomListAdapterHolderPattern holder = (ICustomListAdapterHolderPattern) row.getTag();
		if (holder == null)
		{			
			try 
			{
				holder = (ICustomListAdapterHolderPattern) holderClass.newInstance();
				holder.cacheWidgets(row);
			} 
			catch (IllegalAccessException ex) 
			{
				Log.e(CustomListAdapter.class.toString(), ex.getMessage(), ex);
			} 
			catch (InstantiationException ex) 
			{
				Log.e(CustomListAdapter.class.toString(), ex.getMessage(), ex);
			}
			row.setTag(holder);
		}
		holder.populateHolder(row, position, objects, context, params);
		
		return row;
	}
	
	/**
	 * Returns the number of elements in the adapter.
	 */
	@Override 
	public int getCount()
	{ 
		if (objects == null)
		{
			return 0;
		}
		else
		{
		 return objects.size();
		}
	}
	
	@Override
	public Object getItem(int position)
	{
		return objects.get(position);
	}

	@Override
	public long getItemId(int position)
	{		
		return position;
	}
	
	/* ************************************************************ */
	/*							OTHER            				    */
	/* ************************************************************ */
	
	
	/**
	 * adds elements to the adapter
	 */		
	@SuppressWarnings("unchecked")
	public  void appendData(@SuppressWarnings("rawtypes") Collection objects)
	{
		this.objects.addAll(objects);
		super.notifyDataSetChanged();
	}
	
	
	public void clearData()
	{
		objects.clear();
		super.notifyDataSetChanged();
	}	
	
	
	public List<?> getObjectsUnmodifiable()
	{
		return Collections.unmodifiableList(objects);
	}
	
	//use with caution!!
	public List<?> getObjects()
	{
		return objects;
	}

}
